From cdba1674c5293f5d55c059ada18eb1a1b75cf1e8 Mon Sep 17 00:00:00 2001
From: Paul ProductEngine <pguslisty@productengine.com>
Date: Thu, 22 Sep 2011 13:27:59 +0300
Subject: [PATCH] EXP-1203 ADDITIONAL FIX (As a FUI user, I want the address
 bar and favorites to be on one line)

- Changed member variable name mChevronButton to mMoreTextBox

- Fixed some bugs which PE testers have found:
          1. Parcel characteristics icons from location bar overlay other ui elements
          2. Navigation & Favorites bar are displayed after exitting mouselook mode although 'Show Navigation & Favorites bar' is unchecked
---
 indra/newview/llagent.cpp                     |  2 +-
 indra/newview/llfavoritesbar.cpp              | 30 +++++++++----------
 indra/newview/llfavoritesbar.h                |  2 +-
 .../default/xui/en/panel_navigation_bar.xml   | 16 +++++-----
 4 files changed, 25 insertions(+), 25 deletions(-)

diff --git a/indra/newview/llagent.cpp b/indra/newview/llagent.cpp
index 642a1907f0..1587ed2dd7 100755
--- a/indra/newview/llagent.cpp
+++ b/indra/newview/llagent.cpp
@@ -1797,7 +1797,7 @@ void LLAgent::endAnimationUpdateUI()
 		gViewerWindow->showCursor();
 		// show menus
 		gMenuBarView->setVisible(TRUE);
-		LLNavigationBar::getInstance()->setVisible(TRUE);
+		LLNavigationBar::getInstance()->setVisible(TRUE && gSavedSettings.getBOOL("ShowNavbarNavigationPanel"));
 		gStatusBar->setVisibleForMouselook(true);
 
 		if (gSavedSettings.getBOOL("ShowMiniLocationPanel"))
diff --git a/indra/newview/llfavoritesbar.h b/indra/newview/llfavoritesbar.h
index 3811de3e2f..a41795a080 100644
--- a/indra/newview/llfavoritesbar.h
+++ b/indra/newview/llfavoritesbar.h
@@ -135,7 +135,7 @@ private:
 	BOOL mShowDragMarker;
 	LLUICtrl* mLandingTab;
 	LLUICtrl* mLastTab;
-	LLTextBox* mChevronButton;
+	LLTextBox* mMoreTextBox;
 	LLTextBox* mBarLabel;
 
 	LLUUID mDragItemId;
diff --git a/indra/newview/skins/default/xui/en/panel_navigation_bar.xml b/indra/newview/skins/default/xui/en/panel_navigation_bar.xml
index 9aa2da5abd..54befa38e9 100644
--- a/indra/newview/skins/default/xui/en/panel_navigation_bar.xml
+++ b/indra/newview/skins/default/xui/en/panel_navigation_bar.xml
@@ -9,7 +9,7 @@
  layout="topleft"
  name="navigation_bar"
  chrome="true"
- width="600">
+ width="800">
 	<icon
 	 follows="all"
 	 image_name="NavBar_BG"
@@ -54,15 +54,15 @@
        name="nvp_stack"
        orientation="horizontal"
        top="0"
-       width="600">
+       width="800">
          <layout_panel
            follows="top|left"
            layout="topleft"
            auto_resize="true"
            user_resize="true"
-           min_width="400"
+           min_width="500"
            name="navigation_layout_panel"
-           width="400">
+           width="500">
              <panel
                background_visible="false"
                follows="left|top|right"
@@ -71,7 +71,7 @@
                layout="topleft"
                left="0"
                name="navigation_panel"
-               width="400">
+               width="500">
                  <pull_button
                    follows="left|top"
                    direction="down"
@@ -118,7 +118,7 @@
                    mouse_opaque="false"
                    name="location_combo"
                    top_delta="0"
-                   width="113">
+                   width="213">
                  <combo_list
                    mouse_wheel_opaque="true"/>
                  </location_input>
@@ -174,7 +174,7 @@
            user_resize="true"
            min_width="190"
            name="favorites_layout_panel"
-           width="190">
+           width="290">
              <favorites_bar
                follows="left|right|top"
                font="SansSerifSmall"
@@ -184,7 +184,7 @@
                name="favorite"
                image_drag_indication="Accordion_ArrowOpened_Off"
                tool_tip="Drag Landmarks here for quick access to your favorite places in Second Life!"
-               width="190">
+               width="290">
                  <label
                    follows="left|top"
                    height="15"
diff --git a/indra/newview/llfavoritesbar.cpp b/indra/newview/llfavoritesbar.cpp
index 63519b7c21..e10767af30 100644
--- a/indra/newview/llfavoritesbar.cpp
+++ b/indra/newview/llfavoritesbar.cpp
@@ -390,9 +390,9 @@ LLFavoritesBarCtrl::LLFavoritesBarCtrl(const LLFavoritesBarCtrl::Params& p)
 
 	//make chevron button                                                                                                                               
 	LLTextBox::Params more_button_params(p.more_button);
-	mChevronButton = LLUICtrlFactory::create<LLTextBox> (more_button_params);
-	mChevronButton->setClickedCallback(boost::bind(&LLFavoritesBarCtrl::showDropDownMenu, this));
-	addChild(mChevronButton); 
+	mMoreTextBox = LLUICtrlFactory::create<LLTextBox> (more_button_params);
+	mMoreTextBox->setClickedCallback(boost::bind(&LLFavoritesBarCtrl::showDropDownMenu, this));
+	addChild(mMoreTextBox);
 
 	LLTextBox::Params label_param(p.label);
 	mBarLabel = LLUICtrlFactory::create<LLTextBox> (label_param);
@@ -692,7 +692,7 @@ void LLFavoritesBarCtrl::updateButtons()
 	const child_list_t* childs = getChildList();
 	child_list_const_iter_t child_it = childs->begin();
 	int first_changed_item_index = 0;
-	int rightest_point = getRect().mRight - mChevronButton->getRect().getWidth();
+	int rightest_point = getRect().mRight - mMoreTextBox->getRect().getWidth();
 	//lets find first changed button
 	while (child_it != childs->end() && first_changed_item_index < mItems.count())
 	{
@@ -735,9 +735,9 @@ void LLFavoritesBarCtrl::updateButtons()
 		}
 		// we have to remove ChevronButton to make sure that the last item will be LandmarkButton to get the right aligning
 		// keep in mind that we are cutting all buttons in space between the last visible child of favbar and ChevronButton
-		if (mChevronButton->getParent() == this)
+		if (mMoreTextBox->getParent() == this)
 		{
-			removeChild(mChevronButton);
+			removeChild(mMoreTextBox);
 		}
 		int last_right_edge = 0;
 		//calculate new buttons offset
@@ -777,13 +777,13 @@ void LLFavoritesBarCtrl::updateButtons()
 			S32 buttonHGap = button_params.rect.left; // default value
 			LLRect rect;
 			// Chevron button should stay right aligned
-			rect.setOriginAndSize(getRect().mRight - mChevronButton->getRect().getWidth() - buttonHGap, 0,
-					mChevronButton->getRect().getWidth(),
-					mChevronButton->getRect().getHeight());
+			rect.setOriginAndSize(getRect().mRight - mMoreTextBox->getRect().getWidth() - buttonHGap, 0,
+					mMoreTextBox->getRect().getWidth(),
+					mMoreTextBox->getRect().getHeight());
 
-			addChild(mChevronButton);
-			mChevronButton->setRect(rect);
-			mChevronButton->setVisible(TRUE);
+			addChild(mMoreTextBox);
+			mMoreTextBox->setRect(rect);
+			mMoreTextBox->setVisible(TRUE);
 		}
 		// Update overflow menu
 		LLToggleableMenu* overflow_menu = static_cast <LLToggleableMenu*> (mOverflowMenuHandle.get());
@@ -816,8 +816,8 @@ LLButton* LLFavoritesBarCtrl::createButton(const LLPointer<LLViewerInventoryItem
 	int width = required_width > def_button_width? def_button_width : required_width;
 	LLFavoriteLandmarkButton* fav_btn = NULL;
 
-	// do we have a place for next button + double buttonHGap + mChevronButton ? 
-	if(curr_x + width + 2*button_x_delta +  mChevronButton->getRect().getWidth() > getRect().mRight )
+	// do we have a place for next button + double buttonHGap + mMoreTextBox ?
+	if(curr_x + width + 2*button_x_delta +  mMoreTextBox->getRect().getWidth() > getRect().mRight )
 	{
 		return NULL;
 	}
@@ -967,7 +967,7 @@ void LLFavoritesBarCtrl::showDropDownMenu()
 		menu->buildDrawLabels();
 		menu->updateParent(LLMenuGL::sMenuContainer);
 
-		menu->setButtonRect(mChevronButton->getRect(), this);
+		menu->setButtonRect(mMoreTextBox->getRect(), this);
 
 		LLMenuGL::showPopup(this, menu, getRect().getWidth() - max_width, 0);
 	}
-- 
GitLab